package ru.myitschool.work.ui.login

import android.util.Log
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.launch
import ru.myitschool.work.SessionManager
import ru.myitschool.work.api.ApiService
import ru.myitschool.work.api.UserAuthResponse
import javax.inject.Inject

@HiltViewModel
class LoginViewModel @Inject constructor(
    private val apiService: ApiService
) : ViewModel() {

    private val _state = MutableStateFlow(LoginState())
    val state: StateFlow<LoginState> get() = _state

    fun authenticate(username: String, password: String) {
        if (isValidUsername(username)) {
            viewModelScope.launch {
                try {
                    val response = apiService.authenticate(username, password)
                    Log.d("LoginViewModel", "Response code: ${response.code()}")

                    when (response.code()) {
                        200 -> {
                            val userAuthResponse = response.body() // Получаем JSON-ответ
                            Log.d("LoginViewModel", "User  Auth Response: $userAuthResponse") // Логируем ответ

                            // Обработка JSON-ответа
                            if (userAuthResponse != null) {
                                SessionManager.userLogin = username
                                SessionManager.userRole = userAuthResponse.role // Сохраняем роль
                                _state.value = LoginState(success = true) // Успешная авторизация
                            } else {
                                _state.value = LoginState(error = "Ошибка авторизации: Неверные учетные данные.")
                            }
                        }
                        401 -> {
                            Log.d("LoginViewModel", "Unauthorized access: ${response.message()}")
                            _state.value = LoginState(error = "Ошибка авторизации: Неверные учетные данные.")
                        }
                        400 -> {
                            Log.d("LoginViewModel", "Bad request: ${response.message()}")
                            _state.value = LoginState(error = "Ошибка авторизации: Неправильный запрос.")
                        }
                        else -> {
                            Log.d("LoginViewModel", "Error: ${response.message()}")
                            _state.value = LoginState(error = "Ошибка авторизации: ${response.message()}")
                        }
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                    _state.value = LoginState(error = "Ошибка сети. Проверьте подключение к интернету.")
                }
            }
        } else {
            _state.value = LoginState(error = "Неправильный логин")
        }
    }

    private fun isValidUsername(username: String): Boolean {
        return username.isNotEmpty() // Пример проверки логина
    }
}

// Состояние аутентификации
data class LoginState(
    val success: Boolean = false, // Успешность аутентификации
    val userAuthResponse: UserAuthResponse? = null, // Ответ с информацией о пользователе
    val error: String? = null, // Сообщение об ошибке
    val maintenance: Boolean = false // Состояние техобслуживания
)